# Python_Package
I created this package to generate random password containing at least 1 lowercase, 1 uppercase and 1 number.
You just need to install package by using:-
pip install pkgAnant
import pkgAnant as "module name"
"module name".generate_pass()
